aboutsummaryrefslogtreecommitdiff
path: root/src/main.h
diff options
context:
space:
mode:
authordogecoin <[email protected]>2013-12-25 22:35:09 -0800
committerdogecoin <[email protected]>2013-12-25 22:35:09 -0800
commit2ee5cb3396df66c10fef34480a183d00e3bec635 (patch)
tree0413f70607f4257c5c39ba4dfb7208e18ab8d10a /src/main.h
parentMerge pull request #49 from siavashg/master (diff)
parentadd v1.3 graphic (diff)
downloadarchived-discoin-1.4alpha.tar.xz
archived-discoin-1.4alpha.zip
Merge pull request #52 from billym2k/masterv1.31.4alpha
Fix dust issue
Diffstat (limited to 'src/main.h')
-rw-r--r--src/main.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/main.h b/src/main.h
index c5777c615..eaa807b90 100644
--- a/src/main.h
+++ b/src/main.h
@@ -31,9 +31,9 @@ static const unsigned int MAX_BLOCK_SIZE = 1000000;
static const unsigned int MAX_BLOCK_SIZE_GEN = MAX_BLOCK_SIZE/2;
static const unsigned int MAX_BLOCK_SIGOPS = MAX_BLOCK_SIZE/50;
static const unsigned int MAX_ORPHAN_TRANSACTIONS = MAX_BLOCK_SIZE/100;
-static const int64 MIN_TX_FEE = 10000;
+static const int64 MIN_TX_FEE = 100000000;
static const int64 MIN_RELAY_TX_FEE = MIN_TX_FEE;
-static const int64 MAX_MONEY = 500000000 * COIN; // DogeCoin: maximum of 100B coins (given some randomness), max transaction 500,000,000 for now
+static const int64 MAX_MONEY = 10000000000 * COIN; // DogeCoin: maximum of 100B coins (given some randomness), max transaction 10,000,000,000 for now
inline bool MoneyRange(int64 nValue) { return (nValue >= 0 && nValue <= MAX_MONEY); }
static const int COINBASE_MATURITY = 30;
// Threshold for nLockTime: below this value it is interpreted as block number, otherwise as UNIX timestamp.
@@ -540,7 +540,7 @@ public:
{
// Large (in bytes) low-priority (new, small-coin) transactions
// need a fee.
- return dPriority > COIN * 1440 / 250; // DogeCoin: 1440 blocks found a day. Priority cutoff is 1 dogecoin day / 250 bytes.
+ return dPriority > 100 * COIN * 1440 / 250; // DogeCoin: 1440 blocks found a day. Priority cutoff is 100 dogecoin day / 250 bytes.
}
int64 GetMinFee(unsigned int nBlockSize=1, bool fAllowFree=true, enum GetMinFee_mode mode=GMF_BLOCK) const
@@ -571,7 +571,7 @@ public:
// To limit dust spam, add MIN_TX_FEE/MIN_RELAY_TX_FEE for any output that is less than 0.01
BOOST_FOREACH(const CTxOut& txout, vout)
- if (txout.nValue < CENT)
+ if (txout.nValue < COIN)
nMinFee += nBaseFee;
// Raise the price as the block approaches full